package com.tincancamera.asm.beans;

import java.util.*;

public class ComparatorFactoryTest {
    public static void main (String...args) throws Exception {
        final ComparatorFactory factory = new ComparatorFactory();

        final Bean beta  = new Bean("Beta");
        final Bean alpha = new Bean("Alpha");


        for (String property : "Date:Rank".split(":")) {
            Comparator comparator = factory.createComparator(Bean.class, property);

            System.out.println(property);

            System.out.println(comparator.compare(alpha, beta));
            System.out.println(comparator.compare(alpha, alpha));
            System.out.println(comparator.compare(beta, alpha));

            System.out.println();
        }


        final List<Bean> beans = new ArrayList<Bean>();

        for (int i = 0; i < 100000; ++i) {
            beans.add(new Bean(String.format("Bean_%08d",i)));
        }

        Collections.shuffle(beans);

        for (;;) {
            final long asmTime;
            final long javaTime;


            {
                final List<Bean> toSort = new ArrayList<Bean>(beans);

                final long start = System.currentTimeMillis();

                Collections.sort(toSort, new BeanNameComparator());

                final long elapsed = System.currentTimeMillis() - start;

                javaTime = elapsed;
            }

            {
                final List<Bean> toSort = new ArrayList<Bean>(beans);

                final long start = System.currentTimeMillis();

                Collections.sort(toSort, factory.createComparator(Bean.class, "Name"));

                final long elapsed = System.currentTimeMillis() - start;

                asmTime = elapsed;
            }

            System.out.println("java time: " + javaTime + " ms");
            System.out.println("asm time:  " + asmTime + " ms");
        }
    }
}
